@@ -26,8 +26,6 @@ import pickle
 import sys
 import time
 
-from appdirs import user_cache_dir
-
 from cli.core import keys, settings, sign, upload
 from cli.core.common import CommonLogic
 from cli.ui.menu import Menu
@@ -90,21 +88,18 @@ class Worker(Menu, CommonLogic):
             enc_path = os.path.join(self.cwd, 'config.data.enc')
             if not os.path.exists(dec_path) and not os.path.exists(enc_path):
                 self.initial_setup()
-            # ToDo: Remove in v0.7 or above
-            # Used to help in transition to new app data dir
-            if not hasattr(self.config, 'APP_DATA_DIR') or \
-                    self.config.APP_DATA_DIR is None:
-                company_name = get_correct_answer('Please enter your company '
-                                                  'or name', required=True)
-
-                self.config.APP_DATA_DIR = user_cache_dir(self.config.APP_NAME,
-                                                          company_name)
-                self.save_config(self.config)
 
             x = self.display()
             x()
 
     def quit(self):
+        lex_file = os.path.join(cwd_, 'lextab.py')
+        yac_file = os.path.join(cwd_, 'yacctab.py')
+        if os.path.exists(lex_file):
+            os.remove(lex_file)
+        if os.path.exists(yac_file):
+            os.remove(yac_file)
+
         log.debug('Quitting')
         print_('See Ya!')
         sys.exit()
@@ -119,18 +114,26 @@ class Worker(Menu, CommonLogic):
         self.config.PRIVATE_KEY_NAME = self.config.APP_NAME
         self.config.PUBLIC_KEY_NAME = self.config.APP_NAME
 
-        company_name = get_correct_answer('Please enter your company or name',
-                                          required=True)
+        self.config.COMPANY_NAME = get_correct_answer('Please enter your '
+                                                      'company or name',
+                                                      required=True)
 
-        self.config.APP_DATA_DIR = user_cache_dir(self.config.APP_NAME,
-                                                  company_name)
-        dev_data_dir = get_correct_answer('Enter directory to store'
-                                          ' work files',
-                                          default='Current Working Directory')
+        while 1:
+            dev_data_dir = get_correct_answer('Enter directory to store'
+                                              ' work files',
+                                              default='Current Working '
+                                              'Directory')
+            dev_data_dir = _directory_fixer(dev_data_dir)
+            if os.access(dev_data_dir, os.W_OK) and os.access(dev_data_dir,
+                                                              os.R_OK):
+                self.config.DEV_DATA_DIR = path_fixer(dev_data_dir)
+                break
+            else:
+                self.display_msg('You do not have read/write permission '
+                                 'for this directory')
+                self.display_msg('Press Enter to try a different directory')
+                input_()
 
-        dev_data_dir = _directory_fixer(dev_data_dir)
-
-        self.config.DEV_DATA_DIR = path_fixer(dev_data_dir)
         while 1:
             key_length = get_correct_answer('Enter a key length. Longer is '
                                             'more secure but takes longer '
