@@ -101,7 +101,7 @@ def get_correct_answer(question, default=None, required=False,
         prompt = question + msg + '\n--> '
         if answer is None:
             answer = input_(prompt)
-        if answer == '' and required:
+        if answer == '' and required and default is not None:
             print_('You have to enter a value\n\n')
             input_('Press enter to continue')
             print_('\n\n')
@@ -146,6 +146,9 @@ class SetupConfig(object):
     # If left None "Not_So_TUF" will be used
     APP_NAME = None
 
+    # Company/Your name
+    COMPANY_NAME = None
+
     # Directory for updater to place verified updates.
     APP_DATA_DIR = None
 
@@ -341,17 +344,17 @@ def write_client_config(config_object, test=False):
         else:
             pub_key = None
 
-        if getattr(config_object, 'APP_DATA_DIR', False):
-            app_data_dir = '"{}"'.format(config_object.APP_DATA_DIR)
-        else:
-            app_data_dir = None
+        app_name = '"{}"'.format(config_object.APP_NAME)
+        company_name = '"{}"'.format(config_object.COMPANY_NAME)
 
         with ChDir(package_dir):
             with open('client_config.py', 'w') as f:
                 f.write('class ClientConfig(object):')
                 f.write('\n')
                 f.write('\n')
-                f.write('\tAPP_DATA_DIR = {}'.format(app_data_dir))
+                f.write('\tAPP_NAME = {}'.format(app_name))
+                f.write('\n')
+                f.write('\tCOMPANY_NAME = {}'.format(company_name))
                 f.write('\n')
                 f.write('\tPUBLIC_KEY = {}'.format(pub_key))
                 f.write('\n')
