@@ -27,6 +27,7 @@ import shutil
 import sys
 from zipfile import ZipFile
 
+from not_so_tuf.appdirs import user_cache_dir
 from not_so_tuf.compat import urllib2, execute_permission
 from not_so_tuf.config import Config
 from not_so_tuf.downloader import FileDownloader
@@ -72,7 +73,10 @@ class Client(object):
         # Grabbing config information
         self.update_url = self._fix_update_url(config.get('UPDATE_URL'))
         self.app_name = config.get('APP_NAME', 'Not-So-TUF')
-        self.data_dir = config.get('APP_DATA_DIR', None)
+        self.company_name = config.get('COMPANY_NAME', 'Digital Sapphire')
+
+        self.data_dir = user_cache_dir(self.app_name, self.company_name)
+
         self.public_key = config.get('PUBLIC_KEY', None)
         self.debug = config.get('DEBUG', False)
         self.version_file = 'version.json'
@@ -320,7 +324,7 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
         for d in dirs:
             if not os.path.exists(d):
                 log.debug('Creating directory: {}'.format(d))
-                os.mkdir(d)
+                os.makedirs(d)
 
     def _patch_update(self, name, version):
         # Updates the binary by patching
