@@ -20,9 +20,10 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from __future__ import print_function
+import logging
 import sys
 
+log = logging.getLogger(__name__)
 
 is_py3 = sys.version > '3'
 
@@ -34,22 +35,29 @@ if is_py3:
 else:
     execute_permission = int('755', 8)
 
+
+def print_(*args):
+    for a in args:
+        sys.stdout.write(str(a) + ' ')
+    sys.stdout.write('\n')
+    sys.stdout.flush()
+
 try:
     xrange_ = xrange
-except NameError: # Python 3
+except NameError:  # Python 3
     xrange_ = range
 
 try:
     import urllib2
-except ImportError: # Python 3
+except ImportError:  # Python 3
     import urllib.request as urllib2
 
 try:
     from cStringIO import StringIO as BytesIO
-except ImportError: # Python 3
+except ImportError:  # Python 3
     from io import BytesIO
 
 try:
     input_ = raw_input
-except NameError: # Python 3
+except NameError:  # Python 3
     input_ = input
