@@ -20,13 +20,13 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-import hashlib
 from io import BytesIO
 import logging
 import time
 import sys
 
-from not_so_tuf.compat import urllib2, print_function
+from not_so_tuf.compat import urllib2
+from not_so_tuf.utils import _get_hash
 
 log = logging.getLogger(__name__)
 
@@ -42,7 +42,7 @@ class FileDownloader(object):
 
         url (str): The url to retrieve the file
 
-        hexdigest str(str): The md5 checksum of the file to download
+        hexdigest str(str): The hash checksum of the file to download
     """
     def __init__(self, filename, url, hexdigest):
         self.start = time.time()
@@ -141,7 +141,8 @@ class FileDownloader(object):
             recieved_data += len(file_data)
             end_block = time.time()
             if not file_data:
-                print('\n')
+                sys.stdout.write('\n')
+                sys.stdout.flush()
                 self.my_file.flush()
                 self.my_file.seek(0)
                 self.file_binary_data = self.my_file.read()
@@ -170,17 +171,10 @@ class FileDownloader(object):
         log.debug('Checking file hash')
         log.debug('Update hash: {}'.format(self.hexdigest))
 
-        # ToDo: Remove in version 0.6 or once stable
-        #       md5 has hash collisions. Will change to
-        #       sha256.
-        file_hash = hashlib.sha256(self.file_binary_data).hexdigest()
+        file_hash = _get_hash(self.file_binary_data)
         if file_hash == self.hexdigest:
             return True
 
-        file_hash = hashlib.md5(self.file_binary_data).hexdigest()
-        log.debug('File hash: {}'.format(file_hash))
-        if file_hash == self.hexdigest:
-            return True
         return False
 
     def _get_content_length(self, data):
